.. _linalg:


Linear algebra
**************

.. currentmodule:: networkx

Graph Matrix
------------
.. automodule:: networkx.linalg.graphmatrix
.. autosummary::
   :toctree: generated/

   adjacency_matrix
   incidence_matrix

Laplacian Matrix
----------------
.. automodule:: networkx.linalg.laplacianmatrix
.. autosummary::
   :toctree: generated/

   laplacian_matrix
   normalized_laplacian_matrix
   directed_laplacian_matrix
   directed_combinatorial_laplacian_matrix

Bethe Hessian Matrix
--------------------
.. automodule:: networkx.linalg.bethehessianmatrix
.. autosummary::
   :toctree: generated/

   bethe_hessian_matrix

Algebraic Connectivity
----------------------
.. automodule:: networkx.linalg.algebraicconnectivity
.. autosummary::
   :toctree: generated/

   algebraic_connectivity
   fiedler_vector
   spectral_ordering

Attribute Matrices
------------------

.. automodule:: networkx.linalg.attrmatrix
.. autosummary::
   :toctree: generated/

   attr_matrix
   attr_sparse_matrix

Modularity Matrices
-------------------

.. automodule:: networkx.linalg.modularitymatrix
.. autosummary::
   :toctree: generated/

   modularity_matrix
   directed_modularity_matrix

Spectrum
---------
.. automodule:: networkx.linalg.spectrum
.. autosummary::
   :toctree: generated/

   adjacency_spectrum
   laplacian_spectrum
   bethe_hessian_spectrum
   normalized_laplacian_spectrum
   modularity_spectrum
